#!/bin/bash
# Assume we are ready to set up the upgrade

bootstrap_file=bstrap.bin                                                                
uboot_file=uboot.bin        
files=(${bootstrap_file} ${uboot_file})

uboot_mtd="/dev/$(cat /proc/mtd | grep '\"u-Boot\"' | cut -d : -f 1)"           
if [ ! -c "${uboot_mtd}" ]; then                                                
    echo "No valid MTD partition is labeled u-Boot"                               
    return                                                                        
fi                                                                              
bstrap_mtd="/dev/$(cat /proc/mtd | grep '\"at91bootstrap\"' | cut -d : -f 1)"           
if [ ! -c "${bstrap_mtd}" ]; then                                                
    echo "No valid MTD partition is labeled at91bootstrap"                               
    return                                                                        
fi                                                                              
             
HWVER=$(mts-io-sysfs show hw-version)

if [[ $HWVER =~ MTCDT ]] ; then
	u-boot setenv bootdelay 2
fi

devs=(${bstrap_mtd} ${uboot_mtd})
upgrade_file=upgrade.bin

for (( i = 0; i < ${#files[@]}; i++ )); do                                 
    file=${files[i]}                                                   
    dev=${devs[i]}                     
    if tar -t -f ${upgrade_file} | grep -F -q "${file}"; then         
      if [ "${file}" == "${bootstrap_file}" ] || [ "${file}" == "${uboot_file}" ]; then
        file_size=$(tar -xO -f ${upgrade_file} ${file} | wc -c)           
        if dd if=${dev} bs=${file_size} count=1 | md5sum -c ${file}.md5; then   
          echo "Found ${file} in upgrade but it is the same as current. Continuing..."
          continue                                                              
        fi                                                                      
      fi                                                                        
      echo "Checksum fails, so flashing ${dev} with ${file}..."                                    
                                                                                                                       
      flash_erase -j ${dev} 0 0                                                                
      tar -xO -f ${upgrade_file} ${file} | nandwrite -p ${dev}
    fi                                                                          
done                               
